Index: src/bp-xprofile/bp-xprofile-functions.php
===================================================================
--- src/bp-xprofile/bp-xprofile-functions.php	(revision 10665)
+++ src/bp-xprofile/bp-xprofile-functions.php	(working copy)
@@ -1244,3 +1244,41 @@
 
 	return $field_ids;
 }
+
+/**
+ * Return if a field is the default field (by ID).
+ *
+ * @since 2.6.0
+ *
+ * @param int $field_id ID of field to check.
+ * @return bool
+ */
+function bp_xprofile_is_default_field( $field_id ) {
+	/**
+	 * Filters the default status of a particular field.
+	 *
+	 * @since 2.6.0
+	 *
+	 * @param int $field_id ID of a default field.
+	 */
+	return apply_filters( 'bp_xprofile_is_default_field', (bool) ( 1 === (int) $field_id ), $field_id );
+}
+
+/**
+ * Return if a fields group is the default group (by ID).
+ *
+ * @since 2.6.0
+ *
+ * @param int $group_id ID of group to check.
+ * @return bool
+ */
+function bp_xprofile_is_default_group( $group_id ) {
+	/**
+	 * Filters the default status of a particular fields group.
+	 *
+	 * @since 2.6.0
+	 *
+	 * @param int $group_id ID of a default group.
+	 */
+	return apply_filters( 'bp_xprofile_is_default_group', (bool) ( 1 === (int) $group_id ), $group_id );
+}
Index: src/bp-xprofile/bp-xprofile-caps.php
===================================================================
--- src/bp-xprofile/bp-xprofile-caps.php	(revision 10665)
+++ src/bp-xprofile/bp-xprofile-caps.php	(working copy)
@@ -34,8 +34,8 @@
 			$field_id        = isset( $args[0] ) ? (int)$args[0] : bp_get_the_profile_field_id();
 			$profile_user_id = isset( $args[1] ) ? (int)$args[1] : bp_displayed_user_id();
 
-			// Visibility on the fullname field is not editable.
-			if ( 1 == $field_id ) {
+			// Visibility on the default field is not editable.
+			if ( bp_xprofile_is_default_field( $field_id ) ) {
 				$caps[] = 'do_not_allow';
 				break;
 			}
Index: src/bp-xprofile/classes/class-bp-xprofile-field.php
===================================================================
--- src/bp-xprofile/classes/class-bp-xprofile-field.php	(revision 10665)
+++ src/bp-xprofile/classes/class-bp-xprofile-field.php	(working copy)
@@ -703,8 +703,8 @@
 	 * @return string
 	 */
 	public function get_member_type_label() {
-		// Field 1 is always displayed to everyone, so never gets a label.
-		if ( 1 == $this->id ) {
+		// Default fields are always displayed to everyone, so never get a label.
+		if ( bp_xprofile_is_default_field( $this->id ) ) {
 			return '';
 		}
 
@@ -1326,8 +1326,8 @@
 	 */
 	private function member_type_metabox() {
 
-		// The primary field is for all, so bail.
-		if ( 1 === (int) $this->id ) {
+		// The primary fields are for all, so bail.
+		if ( bp_xprofile_is_default_field( $this->id ) ) {
 			return;
 		}
 
@@ -1548,6 +1548,6 @@
 		}
 
 		// Compare & return.
-		return (bool) ( 1 === (int) $field_id );
+		return bp_xprofile_is_default_field( $field_id );
 	}
 }
